<?php

namespace Otys\OtysPlugin\Includes\OtysApi;

class MatchCriteria extends OtysApiBase
{
    /**
     * Get Matchcriteria List
     *
     * Returns object when succesfull or false when not
     *
     * @since 1.0.0
     *
     * @return mixed
     */
    public function getList(): array
    {
        // Create OWS request
        $matchCriteriaRequest = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.VacancyService.getSearchFacilityInfoNoCache",
            "params" => [
                $this->otysApi->session,
                "ACTONOMY"
            ],
            "id" => 1
        ];

        // Do OWS API Request
        $requestListResult = $this->post($matchCriteriaRequest, true);
    
        // Check if the api call was succesfull and get the result
        if ($requestListResult && ($result  = $requestListResult)) {
            // Return the new generated match criteria list
            return $result['matchcriteria'];
        }

        return [];
    }

    /**
     * Get Matchcriteria list slug based
     *
     * @return array
     *
     * @since 1.0.0
     */
    public function getListSlugs($matchCriteriaToShow = NULL)
    {
        // Get matchcriteria from OWS
        $matchCriteria = $this->getList();

        // Build a new matchcriteria list
        $matchCriteriaList = [];
        
        // Loop through criteria and create slugged list
        foreach ($matchCriteria as $key => $criteria) {
            // Check if we should include this criteria in the list
            if (($matchCriteriaToShow !== NULL && (!is_array($matchCriteriaToShow) || !in_array($key, $matchCriteriaToShow)))) {
                continue;
            }
            
            $slug = sanitize_title($criteria['name']);
            $matchCriteriaList[$slug]['id'] = $key;
            $matchCriteriaList[$slug]['name'] = $criteria['name'];
            $matchCriteriaList[$slug]['active'] = false;
            
            foreach ($criteria['valueOptions'] as $option_id => $option) {
                $option_slug = sanitize_title($option);
                $matchCriteriaList[$slug]['options'][$option_slug]['name'] = $option;
                $matchCriteriaList[$slug]['options'][$option_slug]['id'] = $option_id;
                $matchCriteriaList[$slug]['options'][$option_slug]['frequency'] = 0;
                $matchCriteriaList[$slug]['options'][$option_slug]['active'] = false;
                
                $matchCriteriaList[$slug]['options'][$option_slug]['url'] = '?' . $slug . '=' . $option_slug;
            }
        }
        
        return $matchCriteriaList;
    }
}
