<?php

namespace Otys\OtysPlugin\Includes\OtysApi;

class Vacancies extends OtysApiBase
{
    /**
     * Get Vacancies list
     *
     * @param integer $vacanciesPerPage Amount of vacancies to return per page
     * @param integer $currentPage The current page of vacancies you want to retrieve
     * @param array $args Extra arguments, use OWS formatted arguments to edit the OWS object
     * @return array
     */
    public function getList(int $vacanciesPerPage = 10, int $currentPage = 1, array $args = []): array
    {
        // Init vars
        $offset = ($currentPage - 1) * $vacanciesPerPage;
        $website = intval(get_option('otys_option_website', 0));

        // Merge arguments with default arguments
        $options = array_replace_recursive($default = [
            "search" => [
                "ACTONOMY" => [
                    "DATA" => [
                        "publiceer" => [
                            "options" => [
                                "required" => true,
                                "persistent" => false
                            ],
                            "value" => "1"
                        ]
                    ],
                    "OPTIONS" => [
                        "getTotalCount" => 1,
                        "limit" => $vacanciesPerPage,
                        "offset" => $offset,
                        "sort" => [
                            "SCORE" => "DESC",
                            "entryDateFull" => "DESC"
                        ],
                        "matchCriteriaNames" => 1,
                        "facetsToUse" => [
                            "p_multi",
                            "category",
                            "owner",
                            "pubstatus",
                            "procstatus",
                            "relation",
                            "vacancy_version",
                            "C_12",
                            "C_8",
                            "C_6",
                            "C_10",
                            "C_5"
                        ]
                    ],
                    "VERSION" => 2,
                    "SUB_VERSION" => 0
                ]
            ],
            "limit" => 25,
            "totalCount" => 1,
            "getTotalCount" => true,
            "what" => [
                "uid" => 1,
                "internalId" => 1,
                "title" => 1,
                "location" => 1,
                "relation" => 1,
                "category" => 1,
                "status" => 1,
                "photoFileName" => 1,
                "textField_summary" => 1,
                "applyCount" => 1,
                "matchCriteriaNames" => 1,
                "matchCriteria_1" => 0,
                "matchCriteria_2" => 0,
                "matchCriteria_3" => 0,
                "matchCriteria_4" => 0,
                "matchCriteria_5" => 0,
                "matchCriteria_6" => 0,
                "matchCriteria_7" => 0,
                "matchCriteria_8" => 0, /* diestvb */
                "matchCriteria_9" => 0, /* regio */
                "matchCriteria_10" => 0, /* opleidn */
                "matchCriteria_11" => 0,
                "matchCriteria_12" => 0,
                "matchCriteria_13" => 0,
                "matchCriteria_14" => 0,
                "matchCriteria_15" => 0,
                "matchCriteria_16" => 0,
                "matchCriteria_17" => 0,
                "matchCriteria_18" => 0,
            ]
        ], $args);

        // If a website has been selected we should only retrieve vacancies of that website
        if ($website) {
            $options["search"]["ACTONOMY"]["DATA"]["p_multi"] = [
                "options" => [
                    "required" => true
                ],
                "value" => [
                    "required" => [
                        "{$website}"
                    ]
                ]
            ];
        }

        // Create OWS request
        $vacanciesRequest = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.VacancyService.getListEx",
            "params" => [
                $this->otysApi->session,
                $options
            ],
            "id" => 1
        ];

        // Do OWS API Call
        $vacanciesListResult = $this->post($vacanciesRequest, true);

        if ($vacanciesListResult && ($ows_vacancy_result = $vacanciesListResult)) {
            return $ows_vacancy_result;
        }

        return [];
    }

    /**
     * Get a vacancy by uid
     *
     * @param $uid
     * @return array
     */
    public function get(string $uid = '', $args = [], $mergeDefault = true): array
    {
        if ($uid === '') {
            return [];
        }

        $textFields = $this->getTextFields();

        if ($mergeDefault) {
            $args = array_replace_recursive($default = [
                'uid' => 1,
                'textFieldTitles' => 1,
                'internalId' => 1,
                'entryDateTime' => 1,
                'stopDate' => 1,
                'lastModified' => 1,
                'createdByUser' => 1,
                'modifiedByUser' => 1,
                'title' => 1,
                'copyTitle' => 1,
                'referenceNr' => 1,
                'extraTitle' => 1,
                'indeedMetaData' => 1,
                'salaryCurrency' => 1,
                'salaryValue' => 1,
                'salaryUnit' => 1,
                'searchFunnel' => 1,
                'passive' => 1,
                'planningFilled' => 1,
                'externalReferenceNr' => 1,
                'categoryId' => 1,
                'alternativeCategories' => 1,
                'jobType' => 1,
                'userId' => 1,
                'userId2' => 1,
                'userId3' => 1,
                'defaultConsultant' => 1,
                'userEmail' => 1,
                'listAllEmails' => 1,
                'assignmentDuration' => 1,
                'assignmentTariff' => 1,
                'location' => 1,
                'locationAddress' => 1,
                'customApplyUrl' => 1,
                'locationPostcode' => 1,
                'locationCity' => 1,
                'locationState' => 1,
                'locationCountryCode' => 1,
                'locationLatitude' => 1,
                'locationLongitude' => 1,
                'relation' => 1,
                'relationId' => 1,
                'relationContact' => 1,
                'relationContact2' => 1,
                'relationContactId' => 1,
                'relationContactId2' => 1,
                'viewCount' => 1,
                'applyCount' => 1,
                'emailCount' => 1,
                'candidatesNeeded' => 1,
                'candidatesPlaced' => 1,
                'remarks' => 1,
                'statusId' => 1,
                'published' => 1,
                'otysFrontOfficePreviewUrl' => 1,
                'questionSetId' => 1,
                'photoFileName' => 1,
                'photoThumbFileName' => 1,
                'PhotoGallery' => [
                    'photoId' => 1,
                    'filename' => 1,
                    'thumbFilename' => 1,
                ],
                'Video' => [
                    'videoEmbed' => 1,
                    'videoPosition' => 1,
                ],
                'ConfigurableOrganisationUnits' => [
                    'unitId' => 1,
                    'unitItemId' => 1,
                ],
                'textField_description' => 1,
                'textField_companyProfile' => 1,
                'textField_requirements' => 1,
                'textField_salary' => 1,
                'textField_companyCulture' => 1,
                'textField_summary' => 1,
                'textField_extra1' => 1,
                'textField_extra2' => 1,
                'textField_extra3' => 1,
                'textField_extra4' => 1,
                'textField_extra5' => 1,
                'textField_extra6' => 1,
                'textField_extra7' => 1,
                'textField_extra8' => 1,
                'textField_extra9' => 1,
                'textField_extra10' => 1,
                'assignmentUseEndTime' => 1,
                'assignmentEndTime' => 1,
                'assignmentUseStartTime' => 1,
                'assignmentStartTime' => 1,
                'endDateUnknown' => 1,
                'assignmentEndDate' => 1,
                'assignmentStartDate' => 1,
                'contractSteady' => 1,
                'orgunitCode' => 1,
                'locationCode' => 1,
                'costCentre' => 1,
                'declPeriod' => 1,
                'declPublicTransport' => 1,
                'onlineTimesheets' => 1,
                'hoursType' => 1,
                'hoursUnit' => 1,
                'hours' => 1,
                'housTotal' => 1,
                'tariffUnit' => 1,
                'tariff' => 1,
                'currencyId' => 1,
                'assignmentType' => 1,
                'responsibleCustomerOfficeContactPersonName' => 1,
                'responsibleCustomerOfficeName' => 1,
                'responsibleWorkplaceName' => 1,
                'responsibleWorkplaceContactPersonName' => 1,
                'responsibleContact' => 1,
                'workPlaceAddress' => 1,
                'workPlacePostalCode' => 1,
                'workPlaceCity' => 1,
                'workPlacePhone' => 1,
                'workPlaceFax' => 1,
                'workPlaceDescription' => 1,
                'applicationEmailRecipientRelationContact' => 1,
                'applicationEmailRecipientVacancyOwner' => 1,
                'applicationEmailRecipientVacancyOwnerUsePrintTemplate' => 1,
                'applicationEmailRecipientVacancyOwnerUsePlainTemplate' => 1,
                'applicationEmailRecipientCustom' => 1,
                'applicationEmailSenderCandidate' => 1,
                'applicationEmailPrintTemplateId' => 1,
                'applicationEmailAttachOriginalCv' => 1,
                'applicationEmailUploadedDocs' => 1,
                'applicationEmailNotificationToOrganisationUnit' => 1,
                'applicationEmailRecipientCustomEmail' => 1,
                'vacancyVersion' => 1,
                'VbFtpHtmlSettings' => [
                    'ftpFolder' => 1,
                    'htmlFile' => 1,
                    'active' => 1,
                ],
                'showEmployer' => 1,
                'publishedInShortlist' => 1,
                'blockScanners' => 1,
                'removeApplyButton' => 1,
                'supplierPortal' => 1,
                'publicationStatusId' => 1,
                'publicationStartDate' => 1,
                'publicationEndDate' => 1,
                'publicationFirstDate' => 1,
                'publishedWebsites' => 1,
                'PublishedWebsitesEmails' => [
                    'siteId' => 1,
                    'email' => 1,
                ],
                'publishedInShortlistWebsites' => 1,
                'showLogo' => 1,
                'publishOnJobCent' => 1,
                'publishLanguages' => 1,
                'isMultiSite' => 1,
                'defaultWebsiteId' => 1,
                'searchableInActonomy' => 1,
                'premiumPublish' => 1,
                'VbRefreshPublications' => [
                    'refreshAfterDays' => 1,
                    'emailAfterRenewal' => 1,
                ],
                'premiumPostMultiWebsites' => 1,
                'jobBanner' => 1,
                'jobBannerWebsites' => 1,
                'invoiceCustomerId' => 1,
                'invoiceCustomer' => 1,
                'invoiceCustomerContactId' => 1,
                'extraCategory' => 1,
                'extraLabel' => 1,
                'jobSense' => 1,
                'lmViewers' => 1,
                'jobSpecificEmailSender' => 1,
                'projectsId' => 1,
                'canonicalUrl' => 1,
                'advancedXmlFeeds' => 1,
                'metaTitle' => 1,
                'foReferral' => 1,
                "matchCriteriaNames" => 1,
                "matchCriteria_1" => 0,
                "matchCriteria_2" => 0,
                "matchCriteria_3" => 0,
                "matchCriteria_4" => 0,
                "matchCriteria_5" => 0,
                "matchCriteria_6" => 0,
                "matchCriteria_7" => 0,
                "matchCriteria_8" => 0,
                "matchCriteria_9" => 0,
                "matchCriteria_10" => 0,
                "matchCriteria_11" => 0,
                "matchCriteria_12" => 0,
                "matchCriteria_13" => 0,
                "matchCriteria_14" => 0,
                "matchCriteria_15" => 0,
                "matchCriteria_16" => 0,
                "matchCriteria_17" => 0,
                "matchCriteria_18" => 0,
                "userId" => 1,
                "applicationEmailRecipientVacancyOwner" => 1,
                "applicationEmailRecipientCustom" => 1,
                "applicationEmailRecipientCustomEmail" => 1
            ], $args);
        }

        // Create OWS Request
        $getVacancyRequest = [
            'jsonrpc' => '2.0',
            'method' => 'Otys.Services.VacancyService.getDetail',
            'params' => [
                $this->otysApi->session,
                $uid,
                $args
            ],
            'id' => 1
        ];

        // Do OWS API Call
        $vacancyDetailPost = $this->post($getVacancyRequest, true);

        if ($vacancyDetailPost && ($result = $vacancyDetailPost)) {
            foreach ($textFields as $textField) {
                if ($textField['published']) {
                    $result['textFields'][$textField['owsName']] = [
                        'title' => $result[$textField['owsName']]['title'],
                        'text' => $result[$textField['owsName']]['text']
                    ];
                }
            }

            return $result;
        }

        return [];
    }

    /**
     * Get list of websites
     *
     * @return array
     * @since 1.0.0
     */
    public function getWebsites(): array
    {
        $owsRequest = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.VacancyService.getOptionLists",
            "params" => [
                $this->otysApi->session,
                [
                    "publishedWebsites"
                ]
            ],
            "id" => 9
        ];

        $owsCall = $this->post($owsRequest);
        $owsResult = $owsCall;

        if (!empty($owsResult)) {
            return $owsResult['publishedWebsites'];
        }

        return [];
    }

    /**
     * Get list of all search possibilities in the vacancy list
     *
     * @return array
     * @since 1.0.0
     */
    public function getSearchFacilityInfo(): array
    {
        $owsRequest = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.VacancyService.getSearchFacilityInfoNoCache",
            "params" => [
                $this->otysApi->session,
                "ACTONOMY"
            ],
            "id" => 1
        ];


        $owsCall = $this->post($owsRequest, true);
        $owsResult = $owsCall;


        return $owsResult;
    }

    /**
     * Get Vacancy UID From URL
     *
     * @return string
     * @since 1.0.0
     */
    public function getVacancyUidFromUrl(int $offset = 0)
    {
        global $wp;

        $link = str_replace(get_site_url(), '', home_url($wp->request));
        $link_array = explode('/', $link);

        $array_key = (int) array_key_last($link_array) - (int) $offset;

        $uid = substr($link_array[$array_key], -16);

        return esc_attr($uid);
    }

    /**
     * getFields returns a list of the textfields in OTYS and wheter the textFields are published or not
     * Textfields are based on setting GE127
     *
     * @return array
     * @since 1.0.0
     */
    public function getTextFields(): array
    {
        $owsRequest = [
            "jsonrpc" => "2.0",
            "method" => "Otys.Services.VacancyTextFieldService.getList",
            "params" => [
                $this->otysApi->session
            ],
            "id" => 1
        ];

        $owsCall = $this->post($owsRequest, true);
        $owsResult = $owsCall;

        // Assign the OWS Fieldname to every textField
        foreach ($owsResult as $keyTexTfield => $textField) {
            $owsResult[$keyTexTfield]['owsName'] = $this->getTextFieldsOwsName($textField['field']);
        }

        return $owsResult;
    }

    /**
     * getTextFieldsOwsName
     *
     * @param  mixed $fieldName
     * @return string
     * @since 1.0.0
     */
    public function getTextFieldsOwsName(string $fieldName): string
    {
        $fieldNames = [
            'bedrprofiel' => 'textField_companyProfile',
            'functieo' => 'textField_description',
            'functiee' => 'textField_requirements',
            'sal_o' => 'textField_salary',
            'chapo' => 'textField_summary',
            'bedrcultuur' => 'textField_companyCulture',
            'extra_fld_01' => 'textField_extra1',
            'extra_fld_02' => 'textField_extra2',
            'extra_fld_03' => 'textField_extra3',
            'extra_fld_04' => 'textField_extra4',
            'extra_fld_05' => 'textField_extra5',
            'extra_fld_06' => 'textField_extra6',
            'extra_fld_07' => 'textField_extra7',
            'extra_fld_08' => 'textField_extra8',
            'extra_fld_09' => 'textField_extra9',
            'extra_fld_10' => 'textField_extra10'
        ];

        return array_key_exists($fieldName, $fieldNames) ? $fieldNames[$fieldName] : '';
    }

    /**
     * get Google for jobs mapping and data. Data is based on setting GE214
     *
     * @return array
     * @since 1.0.0
     */
    public function getGoogleForJobs(string $uid): array
    {
        $request = [
            "jsonrpc" => "2.0", 
            "method" => "Otys.Services.GoogleForJobsService.getMappingValues", 
            "params" => [
                    $this->otysApi->session, 
                  "{$uid}"
               ], 
            "id" => 1 
        ];

        return $response = $this->post($request, true);
    }
}
