<?php

namespace Otys\OtysPlugin\Models\Admin;

use Otys\OtysPlugin\Includes\OtysApi\OtysApi;

class AdminSettingsModel extends AdminBaseModel
{
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Create default documents
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDefaultDocuments($apiKey)
    {
        static::createDocumentNewCandidate($apiKey);
        static::createDocumentExistingCandidate($apiKey);
        static::createDocumentOpenCandidate($apiKey);
        static::documentConsultantNotification($apiKey);
        static::createDocumentConfirmEmail($apiKey);
    }
    
    /**
     * Create document which is used for emailing a candidate
     * when the candidate is applying on a vacancy and is a
     * new candidate.
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentNewCandidate($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Nieuwe kandidaat sollicitatie (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Bedankt voor je sollicitatie op de vacature: ««Vacatures.Functienaam»».</p>
            <p>Er is een account voor je aangemaakt waarmee je kunt inloggen in je persoonlijke portaal. Je gebruikersnaam is je email en je wachtwoord is: «password».</p>
            <p>Ga nu direct naar je portaal om je profiel verder aan te vullen: [candidate_profile_page]<br />
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );
        $otysApi->documents->createQuestion($snippetIdNl, 'code', 'code', 'code', 'textField', 'nl');

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Nieuwe kandidaat sollicitatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | New candidate application (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>Thank you for applying on the vacancy ««Vacatures.Functienaam»».</p>
                <p>A account has been created which enables you to login in your personal portal. Your username is your email adres and your password is: «password».</p>
                <p>Go to your profile to make your profile complete [candidate_profile_page]<br />. We also recommend you to change your password.
                Kind regards,<br />',
                true,
                'en'
            );
            $otysApi->documents->createQuestion($snippetIdEn, 'code', 'code', 'code', 'textField', 'en');
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | New candidate application (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
        }
    }

    /**
     * Create document which is used when emailing a candidate when
     * the candidate already exists in OTYS and applies for a new job.
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentExistingCandidate($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Sollicitatie (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Bedankt voor je sollicitatie op de vacature: ««Vacatures.Functienaam»».</p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Sollicitatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Application (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>Thank you for applying on the vacancy ««Vacatures.Functienaam»».</p>
                Kind regards,<br />',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Application (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
        }
    }

    /**
     * Creat a document which is used for emailing the consultant if
     * a candidate applied for a job which the consultant is the owner
     * of.
     *
     * @return void
     * @since 1.1.0
     */
    public static function documentConsultantNotification($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Consultant sollicitatie notificatie (default)',
            '<p>Een kandidaat heeft gesolliciteerd op de vacature ««Vacatures.Functienaam»»</p>
            <p>Kandidaat informatie:</p>
            <p>
                <b>Naam:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Tussenvoegsel»» ««Kandidaten.Achternaam»»<br/>
                <b>Email:</b> ««Kandidaten.Email»»<br/>
                <b>Mobiel:</b> ««Kandidaten.MobilePhone»»<br/>
                <b>Stad:</b> ««Kandidaten.Woonplaats»»
            </p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Consultant sollicitatie notificatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Consultant application notification (default)',
                '<p>A candidate has applied for ««Vacatures.Functienaam»»</p>
                <p>Candidate information:</p>
                <p>
                    <b>Name:</b> ««Kandidaten.Voornaam»» ««Kandidaten.Tussenvoegsel»» ««Kandidaten.Achternaam»»<br/>
                    <b>E-mail:</b> ««Kandidaten.Email»»<br/>
                    <b>Mobile:</b> ««Kandidaten.MobilePhone»»<br/>
                    <b>City:</b> ««Kandidaten.Woonplaats»»
                </p>
                Kind regards,<br />',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Consultant application notification (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
        }
    }

    /**
     * Create a document which is used for emailing the candidate
     * when the candidate did an open application
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentOpenCandidate($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Open sollicitatie (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Bedankt voor jouw open inschrijving.</p>
            <p>Wij zullen z.s.m. contact met je opnemen.</p>
            Met vriendelijke groet,<br />',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Open sollicitatie (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Open application (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>Thank you for your open application.</p>
                <p>We will contact you as soon as possible.</p>
                Kind regards,<br />',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Open application (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
        }
    }

    /**
     * Create a document which is used for sending the candidate a
     * confirmation email
     *
     * @return void
     * @since 1.1.0
     */
    public static function createDocumentConfirmEmail($apiKey)
    {
        $otysApi = new OtysApi($apiKey);

        // nl snippet
        $snippetIdNl = $otysApi->documents->createSnippet(
            'WordPress | Bevestig email (default)',
            '<p>Beste ««Kandidaten.Voornaam»»,</p>
            <p>Je bent aan het solliciteren op de vacature: ««Vacatures.Functienaam»».</p>
            <p>Vul de volgende code op de website in om je sollicitatie af te ronden: «code»</p>
            Met vriendelijke groet,<br/>',
            true,
            'nl'
        );

        /**
         * Start creating documents (begin with parent)
         */
        $documentNameNl = 'WordPress | Bevestig email (default)';
        if (!$otysApi->documents->documentExists($documentNameNl, 'nl')) {
            $documentId = $otysApi->documents->createDocument($documentNameNl, [
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'languageCode' => 'nl'
            ], 'nl');
            
            /**
             * Add other langauges
             */

            /**
             * English language
             */
            $snippetIdEn = $otysApi->documents->createSnippet(
                'WordPress | Confirm email (default)',
                '<p>Dear ««Kandidaten.Voornaam»»,</p>
                <p>You are applying for the vacancy: ««Vacatures.Functienaam»».</p>
                <p>Enter the following code on the website to complete your application: «code»</p>
                With kind regards,<br/>',
                true,
                'en'
            );
            $multilangOuid = $otysApi->documents->getDocumentMultiLangOuid($documentId, 'en');
            
            $documentNameEn = 'WordPress | Confirm email (default)';
            $documentIdEn = $otysApi->documents->createDocument($documentNameEn, [
                'name' => $documentNameEn,
                'multiLangOuid' => $multilangOuid,
                'defaultOutput' => 'Email',
                'isGlobal' => true,
                'defaultFormat' => 'Word',
                'isGlobal' => true,
                'parentUid' => $documentId
            ], 'en');


            /**
             * Add snippets to documents
             */
            $otysApi->documents->addSnippetToDocument($snippetIdNl, $documentId, 'nl');
            $otysApi->documents->addSnippetToDocument($snippetIdEn, $documentIdEn, 'en');
        }
    }
}
