<?php

namespace Otys\OtysPlugin\Shortcodes;

use Otys\OtysPlugin\Includes\Core\Routes;

class ShortcodesBase
{
    /**
     * getShortcodeAttributes
     * Get shortcode attributes from a shortcode within the current post. This
     * function seaches for the shortcode in the $post->post_content and extracts
     * the attributes from the shortcode and returns them as an array
     *
     * @param string $shortcode
     * @return array
     */
    public function getShortcodeAttributes(string $shortcode = '')
    {
        global $post;

        $pattern = get_shortcode_regex();

        if ( 
            preg_match_all( '/'. $pattern .'/s', $post->post_content, $matches )
            && array_key_exists( 2, $matches )
            && in_array( $shortcode, $matches[2] )
        )  {
            $shortcodeKey = array_search($shortcode, $matches[2]);
            $shortCodeString = $matches[3][$shortcodeKey];
            
            $shortcodeAtts = shortcode_parse_atts($shortCodeString);

            if (is_array($shortcodeAtts)) {
                return $shortcodeAtts;
            }

            return [$shortcodeAtts];
        }

        return [];
    }

    /**
     * Load template
     *
     * @param string $template
     * @param array $args
     * @return boolean
     */
    public static function loadTemplate(string $template, array $args = []): bool
    {
        if (($templatePath = Routes::locateTemplate($template)) !== '') {
            load_template($templatePath, false, $args);

            return true;
        }

        return false;
    }
}