<?php

namespace Otys\OtysPlugin\Shortcodes;

use Otys\OtysPlugin\Includes\Core\Shortcodes;
use Otys\OtysPlugin\Includes\Core\Hooks;
use Otys\OtysPlugin\Controllers\VacanciesController;

class VacanciesShortcodes extends ShortcodesBase
{
    /**
     * Constructor
     */
    public function __construct()
    {
        // Register shortcodes
        Shortcodes::add('otys-vacancies-list', $this, 'list');
        Shortcodes::add('otys-vacancies-shortlist', $this, 'shortList');
        Shortcodes::add('otys-vacancies-filters', $this, 'filters');
        Shortcodes::add('otys-vacancies-search', $this, 'search');
        Shortcodes::add('otys-vacancies-apply', $this, 'apply');
        Hooks::addAction('template_redirect', VacanciesController::class, 'processApplyShortcode');
    }

    /**
     * Vacancies list shortcode callback
     *
     * @return mixed
     * @since 1.0.0
     */
    public function list($atts = [], $content = null, $tag = '')
    {
        ob_start();
        $vacancies = new VacanciesController;
        
        $vacancies->list($atts);
        $vacancies->setTemplate('vacancies/vacancies-list.php');
        
        $vacancies->loadTemplate($vacancies->getTemplate(), $vacancies->getArgs());
        
        return ob_get_clean();
    }
    
    /**
     * Vacancies shortlist shortcode callback
     *
     * @return mixed
     * @since 1.0.0
     */
    public function shortList($atts = [], $content = null, $tag = '')
    {
        ob_start();
        $vacancies = new VacanciesController;
        
        $vacancies->shortList($atts);
        $vacancies->loadTemplate($vacancies->getTemplate(), $vacancies->getArgs());
        
        return ob_get_clean();
    }
    
    /**
     * Vacancies search shortcode callback
     */
    public function search($atts = [], $content = null, $tag = '')
    {
        ob_start();
        $vacancies = new VacanciesController;

        $vacancies->search($atts);
        $vacancies->loadTemplate($vacancies->getTemplate(), $vacancies->getArgs());
        
        return ob_get_clean();
    }

    /**
     * Return match criteria filters DOM
     *
     * @return void
     * @since 1.0.0
     */
    public function filters($atts = [], $content = null, $tag = '')
    {
        // TODO create filter for shortcode
        $filtersAts = shortcode_atts(
            array(
            ), $atts, $tag
        );

        $vacancyListAatts = $this->getShortcodeAttributes('otys-vacancies-list');

        $vacancies = new VacanciesController;

        $criteriaSlugs = $vacancies->model->getMatchCriteriaSlugs();

        // get match criteria
        $selectedCriteria = [];
        foreach ($vacancyListAatts as $criteria => $value) {
            // Add criteria based on id's
            if (strpos($criteria, 'criteria-') !== false) {
                $criteriaId = str_replace("criteria-", "C_", $criteria);
                
                $selectedCriteria[$criteriaId] = explode(',', sanitize_key($value));
            }
            
            if (array_key_exists($criteria, $criteriaSlugs)) {
                $selectedCriteria[$criteria] = explode(',', $value);
            }
        }

        $vacancies->filters($selectedCriteria);

        $vacancies->parseArgs('preSelectedCriteria', $selectedCriteria);

        ob_start();

        $vacancies->loadTemplate($vacancies->getTemplate(), $vacancies->getArgs());
        
        return ob_get_clean();
    }

    /**
     * Apply shortcode
     *
     * @param mixed $atts
     * @return void
     */
    public function apply($atts)
    {
        wp_enqueue_script('otys-questionset-js', OTYS_PLUGIN_ASSETS_URL . '/javascript/questionset.js', [], '1.0.0');
        wp_enqueue_script('recaptcha', 'https://www.google.com/recaptcha/api.js');

        $vacancies = new VacanciesController;

        $vacancies->applyShortcode($atts);
        
        ob_start();

        $vacancies->loadTemplate($vacancies->getTemplate(), $vacancies->getArgs());

        return ob_get_clean();
    }
}
