<?php

global $wp;

$args = wp_parse_args(
    $args,
    array(
        'vacancy' => false,
        'questionset' => [],
        'errors' => []
    )
);

do_action('otys_load_script', ['handle' => 'otys-questionset-js','src' => OTYS_PLUGIN_ASSETS_URL . '/javascript/questionset.js']);
do_action('otys_load_script', ['handle' => 'otys-questionset-script','src' => 'https://www.google.com/recaptcha/api.js']);

$currentQuestionPageNumber = (int) $args['questionset']['currentPage'];
$totalQuestionPages = count($args['questionset']['pages']);
$questionset = $args['questionset'];
$currentQuestionPage = $args['questionset']['pages'][$currentQuestionPageNumber];

get_header();
?>

<main id="site-content" role="main">
    <div class="site-width container-fluid">
        <article id="vacancy-apply">
            <header class="vacancy-header">
                <div id="vacancy-apply-header" class="vacancy-spacing">
                    <div class="vacancy-apply-left">
                        <div class="vacancy-head-apply-text">
                            <?php _e('You are currently applying for', 'otys-jobs-apply'); ?>
                        </div>
                        <h1 class="vacancy-title"><?php echo esc_html($args['vacancy']['title']) ?></h1>
                    </div>
                </div>
            </header>

            <section id="vacancy-form" class="vacancy-spacing">
                <form method="POST" class="form_default" enctype="multipart/form-data" id="application-form" name="application-form">
                    
                    <?php if (!empty($args['errors']) && isset($args['errors']['recaptcha'])) : ?>
                    <div class="vacancy-form-errors">
                        <div class="vacancy-form-error">
                            <?php echo esc_html($args['errors']['recaptcha']); ?>
                        </div>
                    </div>
                    <?php endif; ?>

                    <?php
                    foreach ($currentQuestionPage['questions'] as $question) {
                        if (isset($args['formData'][$question['id']])) {
                            $question['value'] = $args['formData'][$question['id']];
                        }

                        ?>
                        <div class="form-input-wrapper">
                            <div class="form-label-col">
                                <label for="vacancy-form-email"><?php echo isset($question['data']['question']) ? esc_html($question['data']['question']) : '' ?><?php echo ($question['validation']['mandatory']) ? '*' : '' ?></label>
                            </div>

                            <div class="form-input-col">
                                <div class="input-wrap">
                                    <div class="input-field">
                                        <?php
                                        load_template(
                                            $question['template'],
                                            false,
                                            [
                                                'question' => $question,
                                                'uid' => $args['vacancy']['uid'],
                                                'ajaxUrl' => $args['ajaxUrl']
                                            ]
                                        );
                                        ?>
                                    </div>

                                    <?php
                                    // If there are errors, display the error
                                    if (array_key_exists($question['id'], $args['errors'])) {
                                        ?>
                                        <div class="input_errors">
                                        <?php
                                            load_template(
                                                $questionset['errorTemplate'],
                                                false,
                                                [
                                                    'errors' => $args['errors'][$question['id']]
                                                ]
                                            );
                                        ?>
                                        </div>
                                        <?php
                                    }
                                    ?>
                                </div>
                            </div>
                        </div>
                        <?php
                    }

                    ?>

                    <div class="form_footer">
                        <input type="hidden" name="uid" value="<?php echo $args['vacancy']['uid'] ?>" />

                        <?php if ($currentQuestionPageNumber === $totalQuestionPages) : ?>
                            <button class="g-recaptcha button vacancy_apply_button" data-sitekey="<?php echo get_option('otys_option_recaptcha_site_key') ?>" data-callback='onSubmit' data-action='submit'><?php echo __('apply', 'otys-jobs-apply'); ?></button>
                        <?php else : ?>
                            <button class="button vacancy_apply_button" type="submit"><?php echo __('apply', 'otys-jobs-apply'); ?></button>
                        <?php endif; ?>
                    </div>
                </form>
            </section>
        </article>
    </div>
</main>

<script>
    function onSubmit(token) {
        document.getElementById("application-form").submit();
    }
</script>

<?php
get_footer();