<?php

/**
 * Routes file
 *
 * Routes registers all public and admin pages
 */

use Otys\OtysPlugin\Includes\Core\Routes;
use Otys\OtysPlugin\Includes\Core\AdminPages;

/**
 *
 * Public pages
 *
 */
$routes = get_option('otys_option_language_routes', '');

if ($routes !== "" && is_array($routes)) {
    foreach ($routes as $module => $moduleRoutes) {
        foreach ($moduleRoutes as $route) {
            /**
             * Vacancies overview routes
            */
            if ($module === 'vacancy') {
                // Vacancy apply
                Routes::add(
                    'vacancy-apply',
                    [
                        'en' => '/' . $route['slug'] . '/:name/apply/',
                        'nl' => '/' . $route['slug'] . '/:name/solliciteer/'
                    ],
                    ['\Otys\OtysPlugin\Controllers\VacanciesController', 'apply'],
                    ['POST', 'GET'],
                    $route['locale']
                );

                // Vacancy confirm email
                Routes::add(
                    'vacancy-apply-confirm-email',
                    [
                        'en' => '/' . $route['slug'] . '/:name/confirm-email/',
                        'nl' => '/' . $route['slug'] . '/:name/bevestig-email/'
                    ],
                    ['\Otys\OtysPlugin\Controllers\VacanciesController', 'confirmEmail'],
                    ['POST', 'GET'],
                    $route['locale']
                );

                // Vacancy succes page
                Routes::add(
                    'vacancy-apply-success',
                    [
                        'en' => '/' . $route['slug'] . '/:name/thank-you/',
                        'nl' => '/' . $route['slug'] . '/:name/bedankt/'
                    ],
                    ['\Otys\OtysPlugin\Controllers\VacanciesController', 'success'],
                    ['POST', 'GET'], 
                    $route['locale']
                );

                // Vacancy Detail
                Routes::add(
                    'vacancy-detail',
                    ['/' . $route['slug'] . '/:name/'],
                    ['\Otys\OtysPlugin\Controllers\VacanciesController', 'detail'],
                    ['POST', 'GET'],
                    $route['locale'],
                    'vacancy',
                    ['\Otys\OtysPlugin\Controllers\VacanciesController', 'detailCallback']
                );
            }
        }
    }
}

// Vacancy ajax
Routes::add(
    'ajax',
    ['/otys-ajax/'], 
    ['\Otys\OtysPlugin\Controllers\VacanciesController', 'ajax'], 
    ['POST', 'GET']
);

/**
 * Webhook routes
 */
// Webhook entry point
Routes::add(
    'webhooks',
    ['/webhooks/'], 
    ['\Otys\OtysPlugin\Controllers\WebhooksController', 'index'], 
    ['POST', 'GET']
);

/**
 *
 * Admin pages
 *
 */
AdminPages::add('OTYS', 'OTYS', 'manage_options', 'otys_settings', ['Otys\OtysPlugin\Controllers\Admin\AdminSettingsController', 'init'], OTYS_PLUGIN_ASSETS_URL . '/images/admin/menu-icon.svg');
AdminPages::addSub('otys_settings', 'OTYS Routes', 'Routes', 'manage_options', 'otys_routes', ['Otys\OtysPlugin\Controllers\Admin\AdminRoutesSettingsController', 'init']);
AdminPages::addSub('otys_settings', 'OTYS Cache management', 'Cache', 'manage_options', 'otys_cache', ['Otys\OtysPlugin\Controllers\Admin\AdminCacheController', 'init']);
AdminPages::addSub('otys_settings', 'OTYS Webooks', 'Webhooks', 'manage_options', 'otys_webhooks', ['Otys\OtysPlugin\Controllers\Admin\AdminWebhooksController', 'init']);
AdminPages::addSub('otys_settings', 'OTYS Logs', 'Logs', 'manage_options', 'otys_logs', ['Otys\OtysPlugin\Controllers\Admin\AdminLogsController', 'init']);
AdminPages::addSub('otys_settings', 'OTYS Guide', 'Instructions', 'manage_options', 'otys_instructions', ['Otys\OtysPlugin\Controllers\Admin\AdminInstructionsController', 'init']);